@@ -17,13 +17,13 @@ from logbook.base import LogRecord, Logger, LoggerGroup, NestedSetup, \
      set_datetime_format
 from logbook.handlers import Handler, StreamHandler, FileHandler, \
      MonitoringFileHandler, StderrHandler, RotatingFileHandler, \
-     TimedRotatingFileHandler, TestHandler, MailHandler, SyslogHandler, \
+     TimedRotatingFileHandler, TestHandler, MailHandler, GMailHandler, SyslogHandler, \
      NullHandler, NTEventLogHandler, create_syshandler, StringFormatter, \
      StringFormatterHandlerMixin, HashingHandlerMixin, \
      LimitingHandlerMixin, WrapperHandler, FingersCrossedHandler, \
      GroupHandler
 
-__version__ = '0.5.0'
+__version__ = '0.6.0'
 
 # create an anonymous default logger and provide all important
 # methods of that logger as global functions
